pub struct Ctrl(/* private fields */);Expand description
System Control Register
Implementations
Sourceimpl Ctrl
impl Ctrl
pub const RESET_OFFSET: usize = 0
pub const RESET_WIDTH: usize = 1
pub const RESET_MASK: u32 = 0x1
pub const RELUCTANCE_OFFSET: usize = 1
pub const RELUCTANCE_WIDTH: usize = 8
pub const RELUCTANCE_MASK: u32 = 0xFF
pub const RELUCTANCE_SIGNED: bool = true
pub const RELUCTANCE_INTWIDTH: isize = 1
pub const RELUCTANCE_FRACWIDTH: isize = 7
pub const DIRACTANCE_OFFSET: usize = 9
pub const DIRACTANCE_WIDTH: usize = 8
pub const DIRACTANCE_MASK: u32 = 0xFF
Sourcepub fn reluctance(&self) -> ReluctanceFixedPoint
pub fn reluctance(&self) -> ReluctanceFixedPoint
Magneto-reluctance
Set the absolute magneto-reluctance.
Sourcepub fn set_reluctance(&mut self, val: ReluctanceFixedPoint)
pub fn set_reluctance(&mut self, val: ReluctanceFixedPoint)
Magneto-reluctance
Set the absolute magneto-reluctance.
Sourcepub fn diractance(&self) -> u8
pub fn diractance(&self) -> u8
Capactive diractance
Capacitive diractance relative to the lunar waneshaft.
The amount of energy that can be stored in a capacitor is E = 1/2 CV^2, but that is irrelevant because nobody knows what ‘diractance’ is, so we’ll leave that as an exercise to the reader.
Sourcepub fn set_diractance(&mut self, val: u8)
pub fn set_diractance(&mut self, val: u8)
Capactive diractance
Capacitive diractance relative to the lunar waneshaft.
The amount of energy that can be stored in a capacitor is E = 1/2 CV^2, but that is irrelevant because nobody knows what ‘diractance’ is, so we’ll leave that as an exercise to the reader.